@@ -43,6 +43,7 @@ cut.tree = c(0, 0),
 transpose = FALSE,
 symkey = TRUE,
 keysize = c(1, 1),
+keysize.label = 1,
 zoom = FALSE,
 title = NULL,
 xlab = NULL,
@@ -189,6 +190,11 @@ name.save = NULL)
     stop("'keysize' must be a numeric vector of length 2.",
     call. = FALSE)
     
+    #-- keysize.label
+    if (length(keysize.label) != 1 || any(!is.finite(keysize)))
+    stop("'keysize' must be a numeric vector of length 1.",
+    call. = FALSE)
+    
     #-- zoom
     if (!is.logical(zoom))
     stop("'zoom' must be a logical constant (TRUE or FALSE).",
@@ -1237,7 +1243,8 @@ name.save = NULL)
     cut.tree = cut.tree,
     transpose = transpose,
     symkey = symkey, 
-    keysize = keysize,            
+    keysize = keysize,
+    keysize.label = keysize.label,
     zoom = zoom, 
     title = title,
     xlab = xlab,
