@@ -127,7 +127,9 @@ multilevel = NULL)    # multilevel is passed to multilevel(design = ) in withinV
         scale = scale,
         logratio = logratio,
         explained_variance = result$explained_variance,#[-result$indY],
-        input.X = result$input.X
+        input.X = result$input.X,
+        mat.c = result$mat.c,
+        defl.matrix = result$defl.matrix
         )
     
     class(out) = c("splsda","spls","DA")
