@@ -50,7 +50,6 @@ tune.splsda = function (X, Y,
 ncomp = 1,
 test.keepX = c(5, 10, 15),
 already.tested.X,
-constraint = FALSE, #if TRUE, expect a list in already.tested.X, otherwise a number(keepX)
 validation = "Mfold",
 folds = 10,
 dist = "max.dist",
@@ -143,6 +142,7 @@ cpus
     #if ((!is.null(already.tested.X)) && (length(already.tested.X) != (ncomp - 1)) )
     #stop("The number of already tested parameters should be NULL or ", ncomp - 1, " since you set ncomp = ", ncomp)
     
+    constraint = FALSE # kept in the code so far, will probably get remove later on
     if (missing(already.tested.X))
     {
         if(constraint == TRUE)
@@ -353,7 +353,6 @@ cpus
         if (progressBar == TRUE)
         cat('\n')
         
-        #save(list=ls(),file="temp.Rdata")
         # calculating the number of optimal component based on t.tests and the error.rate.all, if more than 3 error.rates(repeat>3)
         if(nrepeat > 2 & length(comp.real) >1)
         {
@@ -366,37 +365,19 @@ cpus
             }
             colnames(error.keepX) = c(paste('comp', comp.real, sep=''))
             
-            max = length(comp.real) #number max of components included
-            pval = NULL
-            opt = 1 #initialise the first optimal number of genes
-            alpha = 0.01
-            for(j in 2:max)
-            {
-                pval[j] = NA
-                temp = try(t.test(error.keepX[,opt],error.keepX[,j],alternative="greater")$p.value, silent=T) #t.test of "is adding X comp improves the overall results"
-                if(any(class(temp) == "try-error") || is.na(temp)) # temp can be NaN when error.keepX is constant
-                {
-                    ncomp_opt = NULL
-                    break
-                } else {
-                    pval[j] = temp #had to be two steps (temp then pval =temp) otherwise the class is lost
-                }
-                if( (pval[j]< (alpha)))
-                opt=j #if the p-value is lower than 0.05, the optimal number of comp is updated
-            }
-            if(all(class(temp) != "try-error") & !is.na(temp))
+            opt = t.test.process(error.keepX)
+            
             ncomp_opt = comp.real[opt]
         } else {
             ncomp_opt = error.keepX = NULL
         }
         
-        
         result = list(
         error.rate = mat.mean.error,
         error.rate.sd = mat.sd.error,
         error.rate.all = mat.error.rate,
         choice.keepX = if(constraint){sapply(already.tested.X, length)}else{already.tested.X},
-        choice.keepX.constraint = if(constraint){already.tested.X}else{NULL},
+        #choice.keepX.constraint = if(constraint){already.tested.X}else{NULL},
         choice.ncomp = list(ncomp = ncomp_opt, values = error.keepX),
         error.rate.class = error.per.class.keepX.opt.mean,
         error.rate.class.all = error.per.class.keepX.opt)
@@ -442,4 +423,4 @@ cpus
         return(list(cor.value = cor.value))
 
     }
-}
\ No newline at end of file
+}
